/* Zgv v2.3 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
 * Copyright (C) 1993, 1994 Russell Marks. See README for license details.
 *
 * texterrors.c - provides a fake 'msgbox' routine which printf()'s instead.
 */

#include <stdio.h>


int msgbox(ttyfd,message,replytype,lite,dark,txt)
int ttyfd;
char *message;
int replytype,lite,dark,txt;
{
puts(message);
exit(1);     /* always fatal */
}
